/*
 * CPSC 601.28 - Lecture 5 - Strings and Text
 * Code by David Ledo (dledomai@ucalgary.ca)
 * To run each example/exercise, uncomment desired line and run code
 * Make sure you comment out the other function calls
 */

// Constants
final int SCREEN_WIDTH = 800;
final int SCREEN_HEIGHT = 800;

// Variables

// fonts
PFont helvetica;
PFont georgia;

// declaring the colors
color red = #BE1E2D;
color blue = #308FE0;
color yellow = #FFC531;
color orange = #FF8221;
color green = #5FDB37;
color purple = #A143D1;
color white = #FEFCFF;
color darkGray = #433E3E;

color[] colors = { red, blue, yellow, orange, green, purple, white, darkGray };

// I added one more word here, "t\nw\no", which spells two vertically
// Remember that \n is how we
String[] words = { "hello", "think", "imagine", "make", "create", "colors", "life", "believe", "t \nw\no" };

int[] sizes = { 12, 18, 36, 64, 120, 200 };

PFont[] fonts = new PFont[2]; // we can't do the following: { helvetica, georgia } 
                              // because variables are not initialized yet!

/**
 * Basic string example on the console
 */
void introString()
{
  String s = "hello world";
  println(s + " - " + s.length());
  // prints "hello world - #" (# is length of string) 
}

/**
 * Shows how we can append integers to a string
 * Try tracing the code by hand to see how it works
 */
void appendingExample()
{  
  String s = "hello";
  
  for(int i = 0; i < 10; i++)
  {
    s += i;
    println(s); 
  }
}

/**
 * Draws text on the screen using the default font
 */
void drawSimpleText()
{
  textSize(24);
  fill(0, 0, 0);
  text("hello world!", 50, 50); 
}

/**
 * Writes text using a custom font (tools > create font)
 */
void drawCustomFont()
{
  fill(0, 0, 0);

  // when you created the font, you gave it a default size
  // (in this case 48. Make sure you set the size of the font
  // after you set it.
  textFont(helvetica);
  // make sure to use this AFTER setting the font!
  textSize(250);
  text("hello world!", 350, 350);   
}

/**
 * Draws two pieces of text using different fonts and fills
 */
void drawTwoFonts()
{
  fill(0, 0, 0);
  textFont(helvetica);
  // make sure to use this AFTER setting the font!
  textSize(250);
  text("hello world!", 350, 350); 
  
  fill(255, 0, 0);
  textFont(georgia);
  textSize(100);
  text("Another font! OMG", 200, 200);
}

/**
 * Draws a rectangle with text on top of it
 * making use of textWidth()
 */
void drawRectangleAroundText()
{
  textFont(helvetica);
  // make sure to use this AFTER setting the font!
  textSize(50);

  String toPrint ="hello class!";
  
  // make sure that text size has been set
  // before finding the width
  float widthOfText = textWidth(toPrint);
  
  // draw black rectangle behind text
  fill(0, 0, 0);
  rect(350, 350 - 50, widthOfText + 5, 50 + 5);

  // draw white text
  fill(255, 255, 255);
  text(toPrint, 350, 350); 
  
}

void setup()
{
  background(255, 255, 255);
  size(SCREEN_WIDTH, SCREEN_HEIGHT);
  
  // uncomment function calls to see different examples
  
  // appendingExample();

  // drawSimpleText();

  // here we load the fonts that we created and save
  // them into the variables we created!
  helvetica = loadFont("Helvetica-Bold-48.vlw");
  georgia = loadFont("Georgia-120.vlw");
  
  // the following lines initialize the array of fonts
  // this takes place in setup because we cannot load them early on
  // in the same way that we load ints!
  fonts[0] = helvetica;
  fonts[1] = georgia;
  
  // drawCustomFont();

  // drawTwoFonts();

  // drawRectangleAroundText();
}

/**
 * Draws words at random locations of the screen.
 * The rules of what gets drawn, the sizes, colours and content
 * are determined by a set of arrays declared on the top of this code
 * (global variables)
 */
void drawRandomWords()
{
    int x = int(random(0, SCREEN_WIDTH));
    int y = int(random(0, SCREEN_HEIGHT));
    
    PFont currentFont = fonts[int(random(0, fonts.length))];
  
   // other ways to write this line of code are:
   // Method 1
   // int fontIndex = int(random(0, fonts.length));
   // PFont currentFont = fonts[fontIndex];
   // textFont(currentFont);
   // Method 2
   // textFont(fonts[int(random(0, fonts.length))]);
   
    textFont(currentFont);
    textSize(sizes[int(random(0, sizes.length))]);
  
    textSize(int(random(0, 200)));
    int colorIndex = int(random(0, colors.length));
    color currentFill = colors[colorIndex];
    fill(currentFill, int(random(0, 255)));
    
    int wordIndex = int(random(0, words.length));
    String currentWord = words[wordIndex];
    text(currentWord, x, y);
}

void draw()
{
  // comment out this function call
  // if you wish to run the other examples!
   drawRandomWords();
  
}
